@@ -7,7 +7,7 @@
 #  define VTKIOMYSQL_NO_EXPORT
 #else
 #  ifndef VTKIOMYSQL_EXPORT
-#    ifdef vtkIOMySQL_EXPORTS
+#    ifdef IOMySQL_EXPORTS
         /* We are building this library */
 #      define VTKIOMYSQL_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,25 +23,32 @@
 
 #ifndef VTKIOMYSQL_DEPRECATED
 #  define VTKIOMYSQL_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOMYSQL_DEPRECATED_EXPORT VTKIOMYSQL_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOMYSQL_DEPRECATED_NO_EXPORT VTKIOMYSQL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOMYSQL_NO_DEPRECATED
+#ifndef VTKIOMYSQL_DEPRECATED_EXPORT
+#  define VTKIOMYSQL_DEPRECATED_EXPORT VTKIOMYSQL_EXPORT VTKIOMYSQL_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
+#ifndef VTKIOMYSQL_DEPRECATED_NO_EXPORT
+#  define VTKIOMYSQL_DEPRECATED_NO_EXPORT VTKIOMYSQL_NO_EXPORT VTKIOMYSQL_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOMYSQL_NO_DEPRECATED
+#    define VTKIOMYSQL_NO_DEPRECATED
+#  endif
+#endif
+/* AutoInit dependencies. */
 #include "vtkIOSQLModule.h"
 
-/* AutoInit implementations.  */
-#if defined(vtkIOMySQL_INCLUDE)
-# include vtkIOMySQL_INCLUDE
+
+/* AutoInit implementations. */
+#ifdef vtkIOMySQL_AUTOINIT_INCLUDE
+#include vtkIOMySQL_AUTOINIT_INCLUDE
 #endif
-#if defined(vtkIOMySQL_AUTOINIT)
-# include "vtkAutoInit.h"
-VTK_AUTOINIT(vtkIOMySQL)
+#ifdef vtkIOMySQL_AUTOINIT
+#include "vtkAutoInit.h"
+VTK_MODULE_AUTOINIT(vtkIOMySQL)
 #endif
 
-#endif
+#endif /* VTKIOMYSQL_EXPORT_H */
