@@ -16,11 +16,21 @@
 #define vtk_libproj_h
 
 /* Use the libproj library configured for VTK.  */
-#define VTK_USE_SYSTEM_LIBPROJ
-#ifdef VTK_USE_SYSTEM_LIBPROJ
-# include <proj.h>
-# define ACCEPT_USE_OF_DEPRECATED_PROJ_API_H 1
-# include <proj_api.h>
+#define VTK_MODULE_USE_EXTERNAL_vtklibproj 1
+
+#define VTK_LibPROJ_MAJOR_VERSION 9
+
+#if VTK_LibPROJ_MAJOR_VERSION < 5
+# define PROJ_VERSION_MAJOR 9
+# define proj_list_operations pj_get_list_ref
+#endif
+
+#if VTK_MODULE_USE_EXTERNAL_vtklibproj
+# if VTK_LibPROJ_MAJOR_VERSION >= 5
+#  include <proj.h>
+# else
+#  include <projects.h>
+# endif
 # include <geodesic.h>
 #else
 # include <vtklibproj/src/projects.h>
